==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/SetValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.SetValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties of a overridable value that can be passed to a task template.
 * @property isSecret Flag to indicate whether the value represents a secret or not.
 * @property name The name of the overridable value.
 * @property value The overridable value.
 */
public data class SetValueArgs(
    public val isSecret: Output<Boolean>? = null,
    public val name: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.SetValueArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.SetValueArgs =
        com.pulumi.azurenative.containerregistry.inputs.SetValueArgs.builder()
            .isSecret(isSecret?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SetValueArgs].
 */
@PulumiTagMarker
public class SetValueArgsBuilder internal constructor() {
    private var isSecret: Output<Boolean>? = null

    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Flag to indicate whether the value represents a secret or not.
     */
    @JvmName("reebvtraimydtoiq")
    public suspend fun isSecret(`value`: Output<Boolean>) {
        this.isSecret = value
    }

    /**
     * @param value The name of the overridable value.
     */
    @JvmName("emyjjyvbvlnqgbnn")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The overridable value.
     */
    @JvmName("eyrxosxufybqnmki")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Flag to indicate whether the value represents a secret or not.
     */
    @JvmName("ttybaxdkartsbumo")
    public suspend fun isSecret(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isSecret = mapped
    }

    /**
     * @param value The name of the overridable value.
     */
    @JvmName("icotxwhhdpxwtwhm")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The overridable value.
     */
    @JvmName("cxetpnwswdpwfcan")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): SetValueArgs = SetValueArgs(
        isSecret = isSecret,
        name = name ?: throw PulumiNullFieldException("name"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/SetValueArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.SetValueArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The properties of a overridable value that can be passed to a task template.
 * @property isSecret Flag to indicate whether the value represents a secret or not.
 * @property name The name of the overridable value.
 * @property value The overridable value.
 */
public data class SetValueArgs(
    public val isSecret: Output<Boolean>? = null,
    public val name: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.SetValueArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.SetValueArgs =
        com.pulumi.azurenative.containerregistry.inputs.SetValueArgs.builder()
            .isSecret(isSecret?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SetValueArgs].
 */
@PulumiTagMarker
public class SetValueArgsBuilder internal constructor() {
    private var isSecret: Output<Boolean>? = null

    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Flag to indicate whether the value represents a secret or not.
     */
    @JvmName("gtooxwagwtivjncl")
    public suspend fun isSecret(`value`: Output<Boolean>) {
        this.isSecret = value
    }

    /**
     * @param value The name of the overridable value.
     */
    @JvmName("esoviiewelgfpttu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The overridable value.
     */
    @JvmName("vcgpijvfdgbthxlc")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Flag to indicate whether the value represents a secret or not.
     */
    @JvmName("qgfbhjtuxhlqkwsw")
    public suspend fun isSecret(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isSecret = mapped
    }

    /**
     * @param value The name of the overridable value.
     */
    @JvmName("ahlesilsehrwupvd")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The overridable value.
     */
    @JvmName("biedxnlvscmmimfl")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): SetValueArgs = SetValueArgs(
        isSecret = isSecret,
        name = name ?: throw PulumiNullFieldException("name"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
